@@ -21,15 +21,17 @@ using namespace Qt::Literals::StringLiterals;
 #include "servertest.h"
 #include "transport.h"
 #include "transportmanager.h"
+#include "widgets/transportactivitiesabstractplugin.h"
 #include "widgets/transportconfigwidget_p.h"
 
 #include <QAbstractButton>
 #include <QButtonGroup>
 
-#include "mailtransport_debug.h"
 #include <KAuthorized>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KPluginFactory>
+#include <KPluginMetaData>
 #include <KProtocolInfo>
 
 using namespace MailTransport;
@@ -140,6 +142,7 @@ void SMTPConfigWidget::init()
     d->serverTestFailed = false;
 
     d->ui.setupUi(this);
+    d->ui.tabWidget->tabBar()->setExpanding(true);
     d->ui.password->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
                                                                                                              : KPassword::RevealMode::Never);
     d->manager->addWidget(this); // otherwise it doesn't find out about these widgets
@@ -187,6 +190,21 @@ void SMTPConfigWidget::init()
     }
 
     hostNameChanged(d->transport->host());
+
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim6/mailtransportactivities/kmailtransportactivitiesplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<MailTransport::TransportActivitiesAbstractPlugin>(editWidgetPlugin);
+    if (result) {
+        mTransportActivitiesPlugin = result.plugin;
+    }
+    if (mTransportActivitiesPlugin) {
+        d->ui.tabWidget->addTab(mTransportActivitiesPlugin, i18n("Activities"));
+        TransportActivitiesAbstractPlugin::ActivitySettings settings{
+            d->transport->activities(),
+            d->transport->activitiesEnabled(),
+        };
+        mTransportActivitiesPlugin->setActivitiesSettings(settings);
+    }
 }
 
 void SMTPConfigWidget::enablePasswordLine()
@@ -215,7 +233,7 @@ void SMTPConfigWidget::checkSmtpCapabilities()
     d->ui.checkCapabilitiesStack->setCurrentIndex(1);
     qApp->setOverrideCursor(Qt::BusyCursor);
 
-    connect(d->serverTest, &ServerTest::finished, this, &SMTPConfigWidget::slotFinished);
+    connect(d->serverTest, &ServerTest::finished, this, &SMTPConfigWidget::slotTestFinished);
     connect(d->serverTest, &ServerTest::finished, qApp, []() {
         qApp->restoreOverrideCursor();
     });
@@ -249,6 +267,12 @@ void SMTPConfigWidget::apply()
         d->transport->setEncryption(Transport::EnumEncryption::TLS);
     }
 
+    if (mTransportActivitiesPlugin) {
+        const TransportActivitiesAbstractPlugin::ActivitySettings settings = mTransportActivitiesPlugin->activitiesSettings();
+        d->transport->setActivities(settings.activities);
+        d->transport->setActivitiesEnabled(settings.enabled);
+    }
+
     TransportConfigWidget::apply();
 }
 
@@ -264,8 +288,7 @@ void SMTPConfigWidget::passwordsLoaded()
     }
 }
 
-// TODO rename
-void SMTPConfigWidget::slotFinished(const QList<int> &results)
+void SMTPConfigWidget::slotTestFinished(const QList<int> &results)
 {
     Q_D(SMTPConfigWidget);
 
@@ -277,7 +300,9 @@ void SMTPConfigWidget::slotFinished(const QList<int> &results)
     // If the servertest did not find any usable authentication modes, assume the
     // connection failed and don't disable any of the radioboxes.
     if (results.isEmpty()) {
-        KMessageBox::error(this, i18n("Failed to check capabilities. Please verify port and authentication mode."), i18n("Check Capabilities Failed"));
+        KMessageBox::error(this,
+                           i18n("Failed to check capabilities. Please verify port and authentication mode."),
+                           i18nc("@title:window", "Check Capabilities Failed"));
         d->serverTestFailed = true;
         d->serverTest->deleteLater();
         return;
